<?php

namespace Drupal\mailgo;

use Drupal\Core\Config\Config;
use Drupal\Core\Config\ConfigFactoryInterface;
use Psr\Container\ContainerInterface;

class MailGoManager {
  /**
   * @var Config
   */
  protected $config;

  /**
   * Constructs a new GlobalConfigForm object.
   *
   * @param ConfigFactoryInterface $config_factory
   */
  public function __construct(ConfigFactoryInterface $config_factory) {
    $this->config = $config_factory->get('mailgo.globalconfig');
  }

  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('config.factory')
    );
  }

  /**
   * Get module config
   * @return \Drupal\Core\Config\Config
   */
  public function getConfig() {
    return $this->config;
  }

  /**
   * Set module config
   *
   * @param \Drupal\Core\Config\Config $config
   * @return void
   */
  public function setConfig(Config $config) {
    $this->config = $config;
  }

  /**
   * Replace all emails in text with MailGo links
   *
   * @param string $text Text to be parsed
   * @param bool $noSpam
   *
   * @return string|string[]|null
   */
  public function processEmailsInText(string $text, $noSpam = false) {
    $regex = "/(((?<!\"|')(?<!mailto:|>)[a-z0-9_\-\.]+)@(([a-z0-9\-]+\.([a-z]{2,4})(?:\.[a-z]{2})?)(?!\"|'|<)))/i";
    $replace = $noSpam
      ? "<a href=\"#mailgo\" data-address=\"$2\" data-domain=\"$3\">$1</a>"
      : "<a href=\"mailto:$1\">$1</a>";
    return preg_replace($regex, $replace, $text);
  }

  /**
   * Replace all tel numbers in text with MailGo links
   *
   * @param String $text Text to be parsed
   * @return string|string[]|null
   */
  public function processPhonesInText(string $text) {
    $regex = "/((?<!\"|')(?<!tel:|callto:|>)\+\d{1,3}[\d\s-]{7,}(?!\"|'|<))/";
    $replace = "<a href=\"tel:$1\">$1</a>";
    return preg_replace($regex, $replace, $text);
  }

  /**
   * Make a link with mailto:<email>
   * which won't be affected by MailGo module
   * (for email field only)
   *
   * @param string $email Email address
   * @return string
   */
  public function generateRegularMailToLink(string $email) {
    return sprintf("<a href='mailto:%s' class='no-mailgo'>%s</a>", $email, $email);
  }

  /**
   * This method removes the effect from "_filter_url_parse_email_links" filter
   * (Convert URL into links) in text formatters.
   * To make MailGo filter work properly.
   *
   * @param string $text Text where mailto: links will be striped
   * @return string
   */
  public function stripMailto(string $text) {
    $regex = "/<a(?:.*)href=(?:\"|')mailto:(.+)(?:\"|')(?:.*)>(.+)<\/a>/Ui";
    return preg_replace($regex, "$1", $text);
  }
}

